@@ -167,6 +167,8 @@ class AioHTTPClient(BiliAPIClient):
                 "url": bili_api_resp.url,
             },
         )
+        resp.release()
+        await resp.wait_for_close()
         return bili_api_resp
 
     async def download_create(
@@ -211,6 +213,17 @@ class AioHTTPClient(BiliAPIClient):
         resp = self.__downloads[cnt]
         return int(resp.headers.get("content-length", "0"))
 
+    async def download_close(self, cnt: int) -> None:
+        resp = self.__downloads[cnt]
+        resp.release()
+        await resp.wait_for_close()
+        del self.__downloads[cnt]
+        request_log.dispatch(
+            "DWN_CLOSE",
+            "结束下载",
+            {"id": cnt},
+        )
+
     async def ws_create(
         self, url: str = "", params: dict = {}, headers: dict = {}
     ) -> int:
