@@ -189,7 +189,7 @@ class HTTPXClient(BiliAPIClient):
         )
         req = self.__session.build_request(method="GET", url=url, headers=headers)
         self.__downloads[self.__download_cnt] = await self.__session.send(
-            req, stream=True
+            req, stream=True, follow_redirects=True
         )
         self.__download_iter[self.__download_cnt] = self.__downloads[
             self.__download_cnt
@@ -210,6 +210,17 @@ class HTTPXClient(BiliAPIClient):
         resp = self.__downloads[cnt]
         return int(resp.headers.get("content-length", "0"))
 
+    async def download_close(self, cnt: int) -> None:
+        resp = self.__downloads[cnt]
+        await resp.aclose()
+        del self.__downloads[cnt]
+        del self.__download_iter[cnt]
+        request_log.dispatch(
+            "DWN_CLOSE",
+            "结束下载",
+            {"id": cnt},
+        )
+
     async def ws_create(self, *args, **kwargs) -> None:
         """
         httpx 库暂未实现 WebSocket。相关讨论：<https://github.com/encode/httpx/issues/304>
