@@ -7,6 +7,7 @@ bilibili_api.user
 import json
 import random
 import time
+from datetime import datetime
 from enum import Enum
 from typing import List, Union, Tuple
 
@@ -651,6 +652,52 @@ class User:
         )
         return data
 
+    async def get_upower_qa_list(self, anchor: int = 0):
+        """
+        获取用户充电问答列表。
+
+        Args:
+            anchor (int, optional):     该值为第一次调用本方法时，数据中会有个 anchor 字段，指向下一动态列表第一条动态（类似单向链表）。根据上一次获取结果中的 anchor 字段值，循环填充该值即可获取到全部动态
+
+        Returns:
+            dict: 调用接口返回的内容。
+        """
+        api = API["info"]["upower_qa_list"]
+        params = {
+            'privilege_type': '0',
+            'fans_filter': '0',
+            'up_filter': '0',
+            'ps': '20',
+            'anchor': anchor,
+            'up_mid': self.__uid,
+            't': int(datetime.now().timestamp() * 1000),
+        }
+
+        data = (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
+        return data
+
+    async def get_upower_qa_detail(self, qa_id: int):
+        """
+        获取充电问答详情信息。
+
+        根据问答 ID 获取单条充电问答的详细内容
+
+        Args:
+            qa_id (int): 充电问答的唯一 ID，可从`get_upower_qa_list` 返回的数据中获取。
+        """
+        api = API["info"]["upower_qa_detail"]
+        params = {
+            'qa_id': qa_id,
+            't': int(datetime.now().timestamp() * 1000),
+        }
+
+        data = (
+            await Api(**api, credential=self.credential).update_params(**params).result
+        )
+        return data
+
     async def get_subscribed_bangumi(
         self,
         type_: BangumiType = BangumiType.BANGUMI,
@@ -963,7 +1010,7 @@ class User:
             meta = item["meta"]
             channel_series.channel_meta_cache[
                 str(ChannelSeriesType.SEASON.value) + "-" + str(id_)
-            ] = meta
+                ] = meta
             channels.append(
                 ChannelSeries(
                     self.__uid, ChannelSeriesType.SEASON, id_, self.credential
@@ -974,7 +1021,7 @@ class User:
             meta = item["meta"]
             channel_series.channel_meta_cache[
                 str(ChannelSeriesType.SERIES.value) + "-" + str(id_)
-            ] = meta
+                ] = meta
             channels.append(
                 ChannelSeries(
                     self.__uid, ChannelSeriesType.SERIES, id_, self.credential
@@ -1423,22 +1470,22 @@ async def check_nickname(nick_name: str) -> Tuple[bool, str]:
         return True, ""
 
 
-async def get_self_events(ts: int = 0, credential: Union[Credential, None] = None):
-    """
-    获取自己入站后每一刻的事件
+# async def get_self_events(ts: int = 0, credential: Union[Credential, None] = None):
+#     """
+#     获取自己入站后每一刻的事件
 
-    Args:
-        ts(int, optional)                      : 时间戳. Defaults to 0.
+#     Args:
+#         ts(int, optional)                      : 时间戳. Defaults to 0.
 
-        credential(Credential | None, optional): 凭据. Defaults to None.
+#         credential(Credential | None, optional): 凭据. Defaults to None.
 
-    Returns:
-        dict: 调用 API 返回的结果
-    """
-    credential = credential if credential else Credential()
-    api = API["info"]["events"]
-    params = {"ts": ts}
-    return await Api(**api, credential=credential).update_params(**params).result
+#     Returns:
+#         dict: 调用 API 返回的结果
+#     """
+#     credential = credential if credential else Credential()
+#     api = API["info"]["events"]
+#     params = {"ts": ts}
+#     return await Api(**api, credential=credential).update_params(**params).result
 
 
 async def get_self_notes_info(
