@@ -169,6 +169,7 @@ Events:
 - WS_CLOSE:    关闭 WebSocket 请求。
 - DWN_CREATE:  新建下载。
 - DWN_PART:    部分下载。
+- DWN_CLOSE:   结束下载。
 - (Api)
 - API_REQUEST: Api 请求。
 - API_RESPONSE: Api 响应。
@@ -207,6 +208,7 @@ Events:
 - WS_CLOSE:    关闭 WebSocket 请求。
 - DWN_CREATE:  新建下载。
 - DWN_PART:    部分下载。
+- DWN_CLOSE:   结束下载。
 - (Api)
 - API_REQUEST: Api 请求。
 - API_RESPONSE: Api 响应。
@@ -666,6 +668,16 @@ class BiliAPIClient(ABC):
             """
             raise NotImplementedError
 
+        @abstractmethod
+        async def download_close(self, cnt: int) -> None:
+            """
+            结束下载
+
+            Args:
+                cnt    (int): 下载编号
+            """
+            raise NotImplementedError
+
         @abstractmethod
         async def ws_create(
             self, url: str = "", params: dict = {}, headers: dict = {}
@@ -875,6 +887,16 @@ class BiliAPIClient(ABC):
         """
         raise NotImplementedError
 
+    @abstractmethod
+    async def download_close(self, cnt: int) -> None:
+        """
+        结束下载
+
+        Args:
+            cnt    (int): 下载编号
+        """
+        raise NotImplementedError
+
     @abstractmethod
     async def ws_create(
         self, url: str = "", params: dict = {}, headers: dict = {}
@@ -1137,6 +1159,7 @@ class Credential:
         dedeuserid: Union[str, None] = None,
         ac_time_value: Union[str, None] = None,
         proxy: Union[str, None] = None,
+        **kwargs
     ) -> None:
         """
         各字段获取方式查看：https://nemo2011.github.io/bilibili-api/#/get-credential.md
@@ -1170,6 +1193,9 @@ class Credential:
         self.ac_time_value = ac_time_value
         self.proxy = proxy
 
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
     def get_cookies(self) -> dict:
         """
         获取请求 Cookies 字典
@@ -1187,6 +1213,10 @@ class Credential:
         if self.dedeuserid:
             cookies.update({"DedeUserID": self.dedeuserid})
 
+        for key, value in self.__dict__.items():
+            if key not in cookies and value is not None:
+                cookies[key] = value
+
         return cookies
 
     async def get_buvid_cookies(self) -> dict:
@@ -1350,6 +1380,17 @@ class Credential:
         c.buvid4 = cookies.get("buvid4")
         c.dedeuserid = cookies.get("DedeUserID")
         c.ac_time_value = cookies.get("ac_time_value")
+
+        for key, value in cookies.items():
+            if key not in [
+                "SESSDATA",
+                "bili_jct",
+                "buvid3",
+                "buvid4",
+                "DedeUserID",
+                "ac_time_value",
+            ]:
+                setattr(c, key, value)
         return c
 
     def __str__(self):
@@ -2366,6 +2407,7 @@ async def bili_simple_download(url: str, out: str, intro: str):
             print(f"{intro} - {out} [{bts} / {tot}]", end="\r")
             if bts == tot:
                 break
+    await get_client().download_close(cnt=dwn_id)
     print()
 
 
