@@ -367,6 +367,7 @@ class VideoMeta:
     neutral_mark: Optional[str] = None  # 可选，创作者声明。
     delay_time: Optional[Union[int, datetime]] = None  # 可选，定时发布时间戳（秒）。
     porder: Optional[VideoPorderMeta] = None  # 可选，商业相关参数。
+    watermark: Optional[bool] = False  # 可选，水印
 
     __credential: Credential
     __pre_info = dict
@@ -397,6 +398,7 @@ class VideoMeta:
             Union[int, datetime]
         ] = None,  # 可选，定时发布时间戳（秒）。
         porder: Optional[VideoPorderMeta] = None,  # 可选，商业相关参数。
+        watermark: Optional[bool] = False, # 可选，水印
     ) -> None:
         """
         基本视频上传参数
@@ -447,6 +449,8 @@ class VideoMeta:
             delay_time (Optional[Union[int, datetime]]): 定时发布时间，可选
 
             porder (Optional[VideoPorderMeta]): 商业相关参数，可选
+
+            watermark (Optional[bool]): 是否添加水印，可选，默认为没有水印
         """
         if isinstance(tid, int):
             self.tid = tid
@@ -517,6 +521,7 @@ class VideoMeta:
         elif isinstance(delay_time, datetime):
             self.delay_time = int(delay_time.timestamp())
         self.porder = porder if isinstance(porder, dict) else None
+        self.watermark = watermark
 
     def __dict__(self) -> dict:
         meta = {
@@ -557,6 +562,7 @@ class VideoMeta:
             "up_close_danmu": self.up_close_danmu,
             "web_os": 1,  # const 1
             "source": self.source,
+            "watermark": {"state": 1 if self.watermark else 0},
         }
         for k in copy(meta).keys():
             if meta[k] is None:
